/*
 *  pv_display_lists.h
 *  ProteinViewer
 *
 *  Created by Naoto Morikawa on 6/16/06.
 *  Copyright 2006 Naoto Morikawa. All rights reserved.
 *
 *  2006-10-01 version 0.1 release
 *  2006-11-20 version 0.2 release
 *  2007-04-09 support CO, CB, CG, CU, and CV
 *  2007-04-09 support the color of orange and green
 *  2007-04-15 version 0.3 release
 */

/*
 * void glutSolidSphere(GLdouble radius, GLint slices, GLint stacks);
 */
#define SPHERE_LIST(index, color, shininess, radius) {\
	glNewList(index , GL_COMPILE);\
		glPushAttrib(GL_CURRENT_BIT);\
			glMaterialfv(GL_FRONT, GL_DIFFUSE, color);\
			glMaterialfv(GL_FRONT, GL_SPECULAR, color);\
			glMaterialfv(GL_FRONT, GL_SHININESS, shininess);\
			glutSolidSphere(radius, 10, 10);\
		glPopAttrib();\
	glEndList();\
}

#define CYLINDER_LIST(index, diffuse, specular, shininess, radius) {\
	glNewList(index, GL_COMPILE);\
		glPushAttrib(GL_CURRENT_BIT);\
			glMaterialfv(GL_FRONT, GL_DIFFUSE, diffuse);\
			glMaterialfv(GL_FRONT, GL_SPECULAR, specular);\
			glMaterialfv(GL_FRONT, GL_SHININESS, shininess);\
			glBegin(GL_QUAD_STRIP);\
				glNormal3f(0.0, 0.0, 1.0);\
				glVertex3f(0.0F, 1.0F, 0.15F);\
				glVertex3f(0.0F, 0.0F, 0.15F);\
				for (i = 1; i < 20; i++, Theta += dTheta) {\
					float cs = (float) cos((double)Theta);\
					float sn = (float) sin((double)Theta);\
					float x = radius * sn;\
					float z = radius * cs;\
					glNormal3f(sn, 0.0, cs);\
					glVertex3f(x, 1.0F, z);\
					glVertex3f(x, 0.0F, z);\
				}\
				glNormal3f(0.0, 0.0, 1.0);\
				glVertex3f(0.0F, 1.0F, 0.15F);\
				glVertex3f(0.0F, 0.0F, 0.15F);\
			glEnd();\
		glPopAttrib();\
	glEndList();\
}

/*
 * void glutSolidTetrahedron(void);
 * void glutWireTetrahedron(void);
 */
#define TETRA_LIST(index, angle, rot_x, rot_y, rot_z, color, shininess, func) {\
	glNewList(index, GL_COMPILE);\
		glPushMatrix();\
		glPushAttrib(GL_CURRENT_BIT);\
			glMultMatrixf(Mtile_coor);\
			glRotatef(angle, rot_x, rot_y, rot_z);\
			glRotatef(45.0, 0.0, 0.0, 1.0);\
			glScalef((float) tetra_facter, (float) tetra_facter,\
				 (float) tetra_zfacter);\
			glMaterialfv(GL_FRONT,GL_DIFFUSE, color);\
			glMaterialfv(GL_FRONT,GL_SPECULAR, color);\
			glMaterialfv(GL_FRONT,GL_SHININESS, shininess);\
			glLineWidth(3.0);\
			func();\
		glPopAttrib();\
		glPopMatrix();\
	glEndList();\
}

/* solid tetrahedrons */
GLuint tetra_xyzw;
GLuint tetra_xywz;
GLuint tetra_xzyw;
GLuint tetra_xzwy;
GLuint tetra_xwyz;
GLuint tetra_xwzy;
GLuint tetra2_xyzw;
GLuint tetra2_xywz;
GLuint tetra2_xzyw;
GLuint tetra2_xzwy;
GLuint tetra2_xwyz;
GLuint tetra2_xwzy;
GLfloat tetra_color1[4] = {0.9, 0.7, 0.7, 0.4};		/* pink */
/* GLfloat tetra_color1[4] = {0.6, 0.6, 0.3, 0.4};		 yellow */
GLfloat tetra_color2[4] = {1.0, 0.2, 0.2, 0.4};		/* red */
/* GLfloat tetra_color2[4] = {0.6, 0.3, 0.3, 0.4};		 red */
GLfloat polymer_shininess[1] = {80.0};

/* wire tetrahedrons */
GLuint tetraw_xyzw;
GLuint tetraw_xywz;
GLuint tetraw_xzyw;
GLuint tetraw_xzwy;
GLuint tetraw_xwyz;
GLuint tetraw_xwzy;
GLuint tetra2w_xyzw;
GLuint tetra2w_xywz;
GLuint tetra2w_xzyw;
GLuint tetra2w_xzwy;
GLuint tetra2w_xwyz;
GLuint tetra2w_xwzy;
GLfloat tetra_color1w[4] = {0.9, 0.7, 0.7, 0.1};		/* pink */
/* GLfloat tetra_color1w[4] = {0.6, 0.6, 0.3, 0.1};	 yellow */
GLfloat tetra_color2w[4] = {1.0, 0.2, 0.2, 0.1};		/* red */
/* GLfloat tetra_color2w[4] = {0.6, 0.6, 0.3, 0.1};	 yellow */
GLfloat polymer_shininessw[1] = {80.0};

/* spheres and cylinders */
GLuint sphere_white;
GLuint sphere_50white;
GLuint sphere_yellow;
GLuint sphere_blue;
GLuint sphere_red;
GLuint sphere_green;
GLuint sphere_30black;
GLuint sphere_gray;
GLuint sphere_30blue;
GLuint sphere_30darkblue;
GLuint sphere_30red;
GLuint sphere_30yellow;
GLuint sphere_30orange;	/* NN 2007-04-09 */
GLuint sphere_30white;
GLuint sphere_60red;
GLuint sphere_60yellow;
GLuint sphere_60white;
GLuint sphere_60orange;	/* NN 2007-04-09 */
GLuint sphere_60blue;	/* NN 2007-04-09 */
GLuint sphere_60green;	/* NN 2007-04-09 */
GLuint sphere_30tetra2;
GLuint sphere_tetra1;
GLuint cylinder_2;
GLuint cylinder_5;
GLuint cylinder_10;
GLuint cylinder_1010;
GLuint cylinder_15;
GLuint cylinder_30;
GLuint cylinder_1015;
GLuint cylinder_2015;
GLfloat blue[4] = {0.1, 0.5, 1.0, 1.0};
GLfloat red[4] = {1.0, 0.2, 0.2, 0.75};
/* GLfloat green[4] = {0.2, 1.0, 0.2, 0.75}; *//* NM 2007-04-09 */
GLfloat white[4] = {1.0, 1.0, 1.0, 0.75};
GLfloat yellow[4] = {1.0, 1.0, 0.0, 0.75};
GLfloat orange[4] = {1.0, 174.0/255.0, 0.0, 0.75};		/* NM 2007-04-09 */
GLfloat green[4] = {102.0/255.0, 204.0/255.0, 0.0, 0.75};	/* NM 2007-04-09 */
GLfloat gray[4] = {0.4, 0.4, 0.4, 0.75};
GLfloat black[4] = {0.0, 0.0, 0.0, 0.75};
GLfloat darkblue[4] = {50.0/255.0, 50.0/255.0, 170.0/255.0, 0.75};
GLfloat polymer_diffuse[4] = {0.8F, 0.8F, 0.5F, 1.0F};
GLfloat polymer_specular[4] = {0.5F, 0.5F, 0.4F, 1.0F};
GLfloat dark_shininess[1] = {20.0};
